# -*- coding: utf-8 -*-
from collective.eeafaceted.batchactions.interfaces import IBatchActionsMarker


class IBatchActionsSpecificMarker(IBatchActionsMarker):
    """A marker that is more specific thatn IBatchActionsMarker."""
